"""app URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/4.0/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.conf import settings
from django.conf.urls.static import static
from django.contrib import admin
from django.contrib.auth.views import LogoutView
from django.urls import include, path
from two_factor.urls import urlpatterns as tf_urls

from core.views import base, demo, drugs, notifications, search

urlpatterns = [
    path("__debug__/", include("debug_toolbar.urls")),
    path("", search.DrugsTableView.as_view(), name="home"),
    # path("", base.Home.as_view(), name="home"),
    path("admin/", admin.site.urls),
    # 2FA login urls
    path("", include(tf_urls)),
    path("accounts/signup/", base.Signup.as_view(), name="signup"),
    path("accounts/logout/", LogoutView.as_view(), name="logout"),
    # Demos
    path("demo/modal/", demo.DemoModal.as_view(), name="modal"),
    path("demo/widget/", demo.DemoWidget.as_view(), name="widget"),
    path("demo/window/", demo.DemoWindow.as_view(), name="window"),
    # Notifications
    path(
        "notifications/<str:type>/update/",
        notifications.NotificationsUpdate.as_view(),
        name="notifications_update",
    ),
    path("drugs/<str:type>/", drugs.DrugList.as_view(), name="drugs"),
    path(
        "drugs/<str:type>/create/",
        drugs.DrugCreate.as_view(),
        name="drug_create",
    ),
    path(
        "drugs/<str:type>/update/<str:pk>/",
        drugs.DrugUpdate.as_view(),
        name="drug_update",
    ),
    path(
        "drugs/<str:type>/delete/<str:pk>/",
        drugs.DrugDelete.as_view(),
        name="drug_delete",
    ),
    path(
        "drugs/clear/all/",
        drugs.DrugClear.as_view(),
        name="drug_clear",
    ),
    path(
        "drugs/refresh/all/",
        drugs.DrugPullMerge.as_view(),
        name="drug_pull_merge",
    ),
    # Drug search
    path("search/", search.DrugsTableView.as_view(), name="search"),
    path("search/partial/", search.DrugsTableView.as_view(), name="search_partial"),
] + static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)
